@@ -3,6 +3,7 @@ package git_commands
 import (
 	"fmt"
 	"regexp"
+	"slices"
 	"strconv"
 	"strings"
 	"time"
@@ -14,7 +15,6 @@ import (
 	"github.com/jesseduffield/lazygit/pkg/common"
 	"github.com/jesseduffield/lazygit/pkg/utils"
 	"github.com/samber/lo"
-	"golang.org/x/exp/slices"
 	"golang.org/x/sync/errgroup"
 )
 
@@ -72,9 +72,9 @@ func (self *BranchLoader) Load(reflogCommits []*models.Commit,
 	onWorker func(func() error),
 	renderFunc func(),
 ) ([]*models.Branch, error) {
-	branches := self.obtainBranches(self.version.IsAtLeast(2, 22, 0))
+	branches := self.obtainBranches()
 
-	if self.AppState.LocalBranchSortOrder == "recency" {
+	if self.UserConfig().Git.LocalBranchSortOrder == "recency" {
 		reflogBranches := self.obtainReflogBranches(reflogCommits)
 		// loop through reflog branches. If there is a match, merge them, then remove it from the branches and keep it in the reflog branches
 		branchesWithRecency := make([]*models.Branch, 0)
@@ -95,8 +95,8 @@ func (self *BranchLoader) Load(reflogCommits []*models.Commit,
 
 		// Sort branches that don't have a recency value alphabetically
 		// (we're really doing this for the sake of deterministic behaviour across git versions)
-		slices.SortFunc(branches, func(a *models.Branch, b *models.Branch) bool {
-			return a.Name < b.Name
+		slices.SortFunc(branches, func(a *models.Branch, b *models.Branch) int {
+			return strings.Compare(a.Name, b.Name)
 		})
 
 		branches = utils.Prepend(branches, branchesWithRecency...)
@@ -232,7 +232,7 @@ func (self *BranchLoader) GetBaseBranch(branch *models.Branch, mainBranches *Mai
 	return split[0], nil
 }
 
-func (self *BranchLoader) obtainBranches(canUsePushTrack bool) []*models.Branch {
+func (self *BranchLoader) obtainBranches() []*models.Branch {
 	output, err := self.getRawBranches()
 	if err != nil {
 		panic(err)
@@ -254,8 +254,8 @@ func (self *BranchLoader) obtainBranches(canUsePushTrack bool) []*models.Branch
 			return nil, false
 		}
 
-		storeCommitDateAsRecency := self.AppState.LocalBranchSortOrder != "recency"
-		return obtainBranch(split, storeCommitDateAsRecency, canUsePushTrack), true
+		storeCommitDateAsRecency := self.UserConfig().Git.LocalBranchSortOrder != "recency"
+		return obtainBranch(split, storeCommitDateAsRecency), true
 	})
 }
 
@@ -268,7 +268,7 @@ func (self *BranchLoader) getRawBranches() (string, error) {
 	)
 
 	var sortOrder string
-	switch strings.ToLower(self.AppState.LocalBranchSortOrder) {
+	switch strings.ToLower(self.UserConfig().Git.LocalBranchSortOrder) {
 	case "recency", "date":
 		sortOrder = "-committerdate"
 	case "alphabetical":
@@ -298,7 +298,7 @@ var branchFields = []string{
 }
 
 // Obtain branch information from parsed line output of getRawBranches()
-func obtainBranch(split []string, storeCommitDateAsRecency bool, canUsePushTrack bool) *models.Branch {
+func obtainBranch(split []string, storeCommitDateAsRecency bool) *models.Branch {
 	headMarker := split[0]
 	fullName := split[1]
 	upstreamName := split[2]
@@ -310,12 +310,7 @@ func obtainBranch(split []string, storeCommitDateAsRecency bool, canUsePushTrack
 
 	name := strings.TrimPrefix(fullName, "heads/")
 	aheadForPull, behindForPull, gone := parseUpstreamInfo(upstreamName, track)
-	var aheadForPush, behindForPush string
-	if canUsePushTrack {
-		aheadForPush, behindForPush, _ = parseUpstreamInfo(upstreamName, pushTrack)
-	} else {
-		aheadForPush, behindForPush = aheadForPull, behindForPull
-	}
+	aheadForPush, behindForPush, _ := parseUpstreamInfo(upstreamName, pushTrack)
 
 	recency := ""
 	if storeCommitDateAsRecency {
@@ -361,9 +356,8 @@ func parseDifference(track string, regexStr string) string {
 	match := re.FindStringSubmatch(track)
 	if len(match) > 1 {
 		return match[1]
-	} else {
-		return "0"
 	}
+	return "0"
 }
 
 // TODO: only look at the new reflog commits, and otherwise store the recencies in
