@@ -12,14 +12,14 @@ func TestSyncPush(t *testing.T) {
 	type scenario struct {
 		testName string
 		opts     PushOpts
-		test     func(oscommands.ICmdObj, error)
+		test     func(*oscommands.CmdObj, error)
 	}
 
 	scenarios := []scenario{
 		{
 			testName: "Push with force disabled",
 			opts:     PushOpts{ForceWithLease: false},
-			test: func(cmdObj oscommands.ICmdObj, err error) {
+			test: func(cmdObj *oscommands.CmdObj, err error) {
 				assert.Equal(t, cmdObj.Args(), []string{"git", "push"})
 				assert.NoError(t, err)
 			},
@@ -27,7 +27,7 @@ func TestSyncPush(t *testing.T) {
 		{
 			testName: "Push with force-with-lease enabled",
 			opts:     PushOpts{ForceWithLease: true},
-			test: func(cmdObj oscommands.ICmdObj, err error) {
+			test: func(cmdObj *oscommands.CmdObj, err error) {
 				assert.Equal(t, cmdObj.Args(), []string{"git", "push", "--force-with-lease"})
 				assert.NoError(t, err)
 			},
@@ -35,7 +35,7 @@ func TestSyncPush(t *testing.T) {
 		{
 			testName: "Push with force enabled",
 			opts:     PushOpts{Force: true},
-			test: func(cmdObj oscommands.ICmdObj, err error) {
+			test: func(cmdObj *oscommands.CmdObj, err error) {
 				assert.Equal(t, cmdObj.Args(), []string{"git", "push", "--force"})
 				assert.NoError(t, err)
 			},
@@ -44,11 +44,12 @@ func TestSyncPush(t *testing.T) {
 			testName: "Push with force disabled, upstream supplied",
 			opts: PushOpts{
 				ForceWithLease: false,
+				CurrentBranch:  "master",
 				UpstreamRemote: "origin",
 				UpstreamBranch: "master",
 			},
-			test: func(cmdObj oscommands.ICmdObj, err error) {
-				assert.Equal(t, cmdObj.Args(), []string{"git", "push", "origin", "HEAD:master"})
+			test: func(cmdObj *oscommands.CmdObj, err error) {
+				assert.Equal(t, cmdObj.Args(), []string{"git", "push", "origin", "refs/heads/master:master"})
 				assert.NoError(t, err)
 			},
 		},
@@ -56,12 +57,13 @@ func TestSyncPush(t *testing.T) {
 			testName: "Push with force disabled, setting upstream",
 			opts: PushOpts{
 				ForceWithLease: false,
+				CurrentBranch:  "master-local",
 				UpstreamRemote: "origin",
 				UpstreamBranch: "master",
 				SetUpstream:    true,
 			},
-			test: func(cmdObj oscommands.ICmdObj, err error) {
-				assert.Equal(t, cmdObj.Args(), []string{"git", "push", "--set-upstream", "origin", "HEAD:master"})
+			test: func(cmdObj *oscommands.CmdObj, err error) {
+				assert.Equal(t, cmdObj.Args(), []string{"git", "push", "--set-upstream", "origin", "refs/heads/master-local:master"})
 				assert.NoError(t, err)
 			},
 		},
@@ -69,12 +71,13 @@ func TestSyncPush(t *testing.T) {
 			testName: "Push with force-with-lease enabled, setting upstream",
 			opts: PushOpts{
 				ForceWithLease: true,
+				CurrentBranch:  "master",
 				UpstreamRemote: "origin",
 				UpstreamBranch: "master",
 				SetUpstream:    true,
 			},
-			test: func(cmdObj oscommands.ICmdObj, err error) {
-				assert.Equal(t, cmdObj.Args(), []string{"git", "push", "--force-with-lease", "--set-upstream", "origin", "HEAD:master"})
+			test: func(cmdObj *oscommands.CmdObj, err error) {
+				assert.Equal(t, cmdObj.Args(), []string{"git", "push", "--force-with-lease", "--set-upstream", "origin", "refs/heads/master:master"})
 				assert.NoError(t, err)
 			},
 		},
@@ -86,7 +89,7 @@ func TestSyncPush(t *testing.T) {
 				UpstreamBranch: "master",
 				SetUpstream:    true,
 			},
-			test: func(cmdObj oscommands.ICmdObj, err error) {
+			test: func(cmdObj *oscommands.CmdObj, err error) {
 				assert.Error(t, err)
 				assert.EqualValues(t, "Must specify a remote if specifying a branch", err.Error())
 			},
@@ -106,26 +109,26 @@ func TestSyncFetch(t *testing.T) {
 	type scenario struct {
 		testName       string
 		fetchAllConfig bool
-		test           func(oscommands.ICmdObj)
+		test           func(*oscommands.CmdObj)
 	}
 
 	scenarios := []scenario{
 		{
 			testName:       "Fetch in foreground (all=false)",
 			fetchAllConfig: false,
-			test: func(cmdObj oscommands.ICmdObj) {
+			test: func(cmdObj *oscommands.CmdObj) {
 				assert.True(t, cmdObj.ShouldLog())
 				assert.Equal(t, cmdObj.GetCredentialStrategy(), oscommands.PROMPT)
-				assert.Equal(t, cmdObj.Args(), []string{"git", "fetch"})
+				assert.Equal(t, cmdObj.Args(), []string{"git", "fetch", "--no-write-fetch-head"})
 			},
 		},
 		{
 			testName:       "Fetch in foreground (all=true)",
 			fetchAllConfig: true,
-			test: func(cmdObj oscommands.ICmdObj) {
+			test: func(cmdObj *oscommands.CmdObj) {
 				assert.True(t, cmdObj.ShouldLog())
 				assert.Equal(t, cmdObj.GetCredentialStrategy(), oscommands.PROMPT)
-				assert.Equal(t, cmdObj.Args(), []string{"git", "fetch", "--all"})
+				assert.Equal(t, cmdObj.Args(), []string{"git", "fetch", "--all", "--no-write-fetch-head"})
 			},
 		},
 	}
@@ -144,26 +147,26 @@ func TestSyncFetchBackground(t *testing.T) {
 	type scenario struct {
 		testName       string
 		fetchAllConfig bool
-		test           func(oscommands.ICmdObj)
+		test           func(*oscommands.CmdObj)
 	}
 
 	scenarios := []scenario{
 		{
 			testName:       "Fetch in background (all=false)",
 			fetchAllConfig: false,
-			test: func(cmdObj oscommands.ICmdObj) {
+			test: func(cmdObj *oscommands.CmdObj) {
 				assert.False(t, cmdObj.ShouldLog())
 				assert.Equal(t, cmdObj.GetCredentialStrategy(), oscommands.FAIL)
-				assert.Equal(t, cmdObj.Args(), []string{"git", "fetch"})
+				assert.Equal(t, cmdObj.Args(), []string{"git", "fetch", "--no-write-fetch-head"})
 			},
 		},
 		{
 			testName:       "Fetch in background (all=true)",
 			fetchAllConfig: true,
-			test: func(cmdObj oscommands.ICmdObj) {
+			test: func(cmdObj *oscommands.CmdObj) {
 				assert.False(t, cmdObj.ShouldLog())
 				assert.Equal(t, cmdObj.GetCredentialStrategy(), oscommands.FAIL)
-				assert.Equal(t, cmdObj.Args(), []string{"git", "fetch", "--all"})
+				assert.Equal(t, cmdObj.Args(), []string{"git", "fetch", "--all", "--no-write-fetch-head"})
 			},
 		},
 	}
