@@ -1,8 +1,6 @@
 package git_commands
 
 import (
-	"fmt"
-	"os"
 	"testing"
 
 	"github.com/go-errors/errors"
@@ -12,8 +10,6 @@ import (
 	"github.com/stretchr/testify/assert"
 )
 
-var disableHooksFlag = fmt.Sprintf("core.hooksPath=%s", os.DevNull)
-
 func TestWorkingTreeStageFile(t *testing.T) {
 	runner := oscommands.NewFakeRunner(t).
 		ExpectGitArgs([]string{"add", "--", "test.txt"}, "", nil)
@@ -30,7 +26,7 @@ func TestWorkingTreeStageFiles(t *testing.T) {
 
 	instance := buildWorkingTreeCommands(commonDeps{runner: runner})
 
-	assert.NoError(t, instance.StageFiles([]string{"test.txt", "test2.txt"}))
+	assert.NoError(t, instance.StageFiles([]string{"test.txt", "test2.txt"}, nil))
 	runner.CheckForMissingCalls()
 }
 
@@ -87,7 +83,7 @@ func TestWorkingTreeDiscardAllFileChanges(t *testing.T) {
 		{
 			testName: "An error occurred when resetting",
 			file: &models.File{
-				Name:             "test",
+				Path:             "test",
 				HasStagedChanges: true,
 			},
 			removeFile: func(string) error { return nil },
@@ -98,7 +94,7 @@ func TestWorkingTreeDiscardAllFileChanges(t *testing.T) {
 		{
 			testName: "An error occurred when removing file",
 			file: &models.File{
-				Name:    "test",
+				Path:    "test",
 				Tracked: false,
 				Added:   true,
 			},
@@ -111,57 +107,57 @@ func TestWorkingTreeDiscardAllFileChanges(t *testing.T) {
 		{
 			testName: "An error occurred with checkout",
 			file: &models.File{
-				Name:             "test",
+				Path:             "test",
 				Tracked:          true,
 				HasStagedChanges: false,
 			},
 			removeFile: func(string) error { return nil },
 			runner: oscommands.NewFakeRunner(t).
-				ExpectGitArgs([]string{"-c", disableHooksFlag, "checkout", "--", "test"}, "", errors.New("error")),
+				ExpectGitArgs([]string{"checkout", "--", "test"}, "", errors.New("error")),
 			expectedError: "error",
 		},
 		{
 			testName: "Checkout only",
 			file: &models.File{
-				Name:             "test",
+				Path:             "test",
 				Tracked:          true,
 				HasStagedChanges: false,
 			},
 			removeFile: func(string) error { return nil },
 			runner: oscommands.NewFakeRunner(t).
-				ExpectGitArgs([]string{"-c", disableHooksFlag, "checkout", "--", "test"}, "", nil),
+				ExpectGitArgs([]string{"checkout", "--", "test"}, "", nil),
 			expectedError: "",
 		},
 		{
 			testName: "Reset and checkout staged changes",
 			file: &models.File{
-				Name:             "test",
+				Path:             "test",
 				Tracked:          true,
 				HasStagedChanges: true,
 			},
 			removeFile: func(string) error { return nil },
 			runner: oscommands.NewFakeRunner(t).
 				ExpectGitArgs([]string{"reset", "--", "test"}, "", nil).
-				ExpectGitArgs([]string{"-c", disableHooksFlag, "checkout", "--", "test"}, "", nil),
+				ExpectGitArgs([]string{"checkout", "--", "test"}, "", nil),
 			expectedError: "",
 		},
 		{
 			testName: "Reset and checkout merge conflicts",
 			file: &models.File{
-				Name:              "test",
+				Path:              "test",
 				Tracked:           true,
 				HasMergeConflicts: true,
 			},
 			removeFile: func(string) error { return nil },
 			runner: oscommands.NewFakeRunner(t).
 				ExpectGitArgs([]string{"reset", "--", "test"}, "", nil).
-				ExpectGitArgs([]string{"-c", disableHooksFlag, "checkout", "--", "test"}, "", nil),
+				ExpectGitArgs([]string{"checkout", "--", "test"}, "", nil),
 			expectedError: "",
 		},
 		{
 			testName: "Reset and remove",
 			file: &models.File{
-				Name:             "test",
+				Path:             "test",
 				Tracked:          false,
 				Added:            true,
 				HasStagedChanges: true,
@@ -177,7 +173,7 @@ func TestWorkingTreeDiscardAllFileChanges(t *testing.T) {
 		{
 			testName: "Remove only",
 			file: &models.File{
-				Name:             "test",
+				Path:             "test",
 				Tracked:          false,
 				Added:            true,
 				HasStagedChanges: false,
@@ -224,7 +220,7 @@ func TestWorkingTreeDiff(t *testing.T) {
 		{
 			testName: "Default case",
 			file: &models.File{
-				Name:             "test.txt",
+				Path:             "test.txt",
 				HasStagedChanges: false,
 				Tracked:          true,
 			},
@@ -239,7 +235,7 @@ func TestWorkingTreeDiff(t *testing.T) {
 		{
 			testName: "cached",
 			file: &models.File{
-				Name:             "test.txt",
+				Path:             "test.txt",
 				HasStagedChanges: false,
 				Tracked:          true,
 			},
@@ -254,7 +250,7 @@ func TestWorkingTreeDiff(t *testing.T) {
 		{
 			testName: "plain",
 			file: &models.File{
-				Name:             "test.txt",
+				Path:             "test.txt",
 				HasStagedChanges: false,
 				Tracked:          true,
 			},
@@ -269,7 +265,7 @@ func TestWorkingTreeDiff(t *testing.T) {
 		{
 			testName: "File not tracked and file has no staged changes",
 			file: &models.File{
-				Name:             "test.txt",
+				Path:             "test.txt",
 				HasStagedChanges: false,
 				Tracked:          false,
 			},
@@ -284,7 +280,7 @@ func TestWorkingTreeDiff(t *testing.T) {
 		{
 			testName: "Default case (ignore whitespace)",
 			file: &models.File{
-				Name:             "test.txt",
+				Path:             "test.txt",
 				HasStagedChanges: false,
 				Tracked:          true,
 			},
@@ -299,7 +295,7 @@ func TestWorkingTreeDiff(t *testing.T) {
 		{
 			testName: "Show diff with custom context size",
 			file: &models.File{
-				Name:             "test.txt",
+				Path:             "test.txt",
 				HasStagedChanges: false,
 				Tracked:          true,
 			},
@@ -314,7 +310,7 @@ func TestWorkingTreeDiff(t *testing.T) {
 		{
 			testName: "Show diff with custom similarity threshold",
 			file: &models.File{
-				Name:             "test.txt",
+				Path:             "test.txt",
 				HasStagedChanges: false,
 				Tracked:          true,
 			},
@@ -331,15 +327,14 @@ func TestWorkingTreeDiff(t *testing.T) {
 	for _, s := range scenarios {
 		t.Run(s.testName, func(t *testing.T) {
 			userConfig := config.GetDefaultConfig()
-			appState := &config.AppState{}
-			appState.IgnoreWhitespaceInDiffView = s.ignoreWhitespace
-			appState.DiffContextSize = s.contextSize
-			appState.RenameSimilarityThreshold = s.similarityThreshold
+			userConfig.Git.IgnoreWhitespaceInDiffView = s.ignoreWhitespace
+			userConfig.Git.DiffContextSize = s.contextSize
+			userConfig.Git.RenameSimilarityThreshold = s.similarityThreshold
 			repoPaths := RepoPaths{
 				worktreePath: "/path/to/worktree",
 			}
 
-			instance := buildWorkingTreeCommands(commonDeps{runner: s.runner, userConfig: userConfig, appState: appState, repoPaths: &repoPaths})
+			instance := buildWorkingTreeCommands(commonDeps{runner: s.runner, userConfig: userConfig, appState: &config.AppState{}, repoPaths: &repoPaths})
 			result := instance.WorktreeFileDiff(s.file, s.plain, s.cached)
 			assert.Equal(t, expectedResult, result)
 			s.runner.CheckForMissingCalls()
@@ -400,14 +395,13 @@ func TestWorkingTreeShowFileDiff(t *testing.T) {
 	for _, s := range scenarios {
 		t.Run(s.testName, func(t *testing.T) {
 			userConfig := config.GetDefaultConfig()
-			appState := &config.AppState{}
-			appState.IgnoreWhitespaceInDiffView = s.ignoreWhitespace
-			appState.DiffContextSize = s.contextSize
+			userConfig.Git.IgnoreWhitespaceInDiffView = s.ignoreWhitespace
+			userConfig.Git.DiffContextSize = s.contextSize
 			repoPaths := RepoPaths{
 				worktreePath: "/path/to/worktree",
 			}
 
-			instance := buildWorkingTreeCommands(commonDeps{runner: s.runner, userConfig: userConfig, appState: appState, repoPaths: &repoPaths})
+			instance := buildWorkingTreeCommands(commonDeps{runner: s.runner, userConfig: userConfig, appState: &config.AppState{}, repoPaths: &repoPaths})
 
 			result, err := instance.ShowFileDiff(s.from, s.to, s.reverse, "test.txt", s.plain)
 			assert.NoError(t, err)
@@ -432,7 +426,7 @@ func TestWorkingTreeCheckoutFile(t *testing.T) {
 			commitHash: "11af912",
 			fileName:   "test999.txt",
 			runner: oscommands.NewFakeRunner(t).
-				ExpectGitArgs([]string{"-c", disableHooksFlag, "checkout", "11af912", "--", "test999.txt"}, "", nil),
+				ExpectGitArgs([]string{"checkout", "11af912", "--", "test999.txt"}, "", nil),
 			test: func(err error) {
 				assert.NoError(t, err)
 			},
@@ -442,7 +436,7 @@ func TestWorkingTreeCheckoutFile(t *testing.T) {
 			commitHash: "11af912",
 			fileName:   "test999.txt",
 			runner: oscommands.NewFakeRunner(t).
-				ExpectGitArgs([]string{"-c", disableHooksFlag, "checkout", "11af912", "--", "test999.txt"}, "", errors.New("error")),
+				ExpectGitArgs([]string{"checkout", "11af912", "--", "test999.txt"}, "", errors.New("error")),
 			test: func(err error) {
 				assert.Error(t, err)
 			},
@@ -470,9 +464,9 @@ func TestWorkingTreeDiscardUnstagedFileChanges(t *testing.T) {
 	scenarios := []scenario{
 		{
 			testName: "valid case",
-			file:     &models.File{Name: "test.txt"},
+			file:     &models.File{Path: "test.txt"},
 			runner: oscommands.NewFakeRunner(t).
-				ExpectGitArgs([]string{"-c", disableHooksFlag, "checkout", "--", "test.txt"}, "", nil),
+				ExpectGitArgs([]string{"checkout", "--", "test.txt"}, "", nil),
 			test: func(err error) {
 				assert.NoError(t, err)
 			},
@@ -499,7 +493,7 @@ func TestWorkingTreeDiscardAnyUnstagedFileChanges(t *testing.T) {
 		{
 			testName: "valid case",
 			runner: oscommands.NewFakeRunner(t).
-				ExpectGitArgs([]string{"-c", disableHooksFlag, "checkout", "--", "."}, "", nil),
+				ExpectGitArgs([]string{"checkout", "--", "."}, "", nil),
 			test: func(err error) {
 				assert.NoError(t, err)
 			},
