@@ -12,10 +12,6 @@ import (
 	"github.com/samber/lo"
 )
 
-type ICommitsHelper interface {
-	UpdateCommitPanelView(message string)
-}
-
 type CommitsHelper struct {
 	c *HelperCommon
 
@@ -26,8 +22,6 @@ type CommitsHelper struct {
 	setCommitDescription          func(string)
 }
 
-var _ ICommitsHelper = &CommitsHelper{}
-
 func NewCommitsHelper(
 	c *HelperCommon,
 	getCommitSummary func() string,
@@ -56,7 +50,7 @@ func (self *CommitsHelper) SetMessageAndDescriptionInView(message string) {
 
 	self.setCommitSummary(summary)
 	self.setCommitDescription(description)
-	self.c.Contexts().CommitMessage.RenderCommitLength()
+	self.c.Contexts().CommitMessage.RenderSubtitle()
 }
 
 func (self *CommitsHelper) JoinCommitMessageAndUnwrappedDescription() string {
@@ -129,6 +123,14 @@ type OpenCommitMessagePanelOpts struct {
 	OnConfirm        func(summary string, description string) error
 	OnSwitchToEditor func(string) error
 	InitialMessage   string
+
+	// The following two fields are only for the display of the "(hooks
+	// disabled)" display in the commit message panel. They have no effect on
+	// the actual behavior; make sure what you are passing in matches that.
+	// Leave unassigned if the concept of skipping hooks doesn't make sense for
+	// what you are doing, e.g. when creating a tag.
+	ForceSkipHooks  bool
+	SkipHooksPrefix string
 }
 
 func (self *CommitsHelper) OpenCommitMessagePanel(opts *OpenCommitMessagePanelOpts) {
@@ -146,18 +148,17 @@ func (self *CommitsHelper) OpenCommitMessagePanel(opts *OpenCommitMessagePanelOp
 		opts.InitialMessage,
 		onConfirm,
 		opts.OnSwitchToEditor,
+		opts.ForceSkipHooks,
+		opts.SkipHooksPrefix,
 	)
 
 	self.UpdateCommitPanelView(opts.InitialMessage)
 
-	self.c.Context().Push(self.c.Contexts().CommitMessage)
+	self.c.Context().Push(self.c.Contexts().CommitMessage, types.OnFocusOpts{})
 }
 
-func (self *CommitsHelper) OnCommitSuccess() {
-	// if we have a preserved message we want to clear it on success
-	if self.c.Contexts().CommitMessage.GetPreserveMessage() {
-		self.c.Contexts().CommitMessage.SetPreservedMessageAndLogError("")
-	}
+func (self *CommitsHelper) ClearPreservedCommitMessage() {
+	self.c.Contexts().CommitMessage.SetPreservedMessageAndLogError("")
 }
 
 func (self *CommitsHelper) HandleCommitConfirm() error {
@@ -255,13 +256,8 @@ func (self *CommitsHelper) pasteCommitMessageFromClipboard() error {
 		return nil
 	}
 
-	if currentMessage := self.JoinCommitMessageAndUnwrappedDescription(); currentMessage == "" {
-		self.SetMessageAndDescriptionInView(message)
-		return nil
-	}
-
-	// Confirm before overwriting the commit message
-	self.c.Confirm(types.ConfirmOpts{
+	currentMessage := self.JoinCommitMessageAndUnwrappedDescription()
+	return self.c.ConfirmIf(currentMessage != "", types.ConfirmOpts{
 		Title:  self.c.Tr.PasteCommitMessageFromClipboard,
 		Prompt: self.c.Tr.SurePasteCommitMessage,
 		HandleConfirm: func() error {
@@ -269,6 +265,4 @@ func (self *CommitsHelper) pasteCommitMessageFromClipboard() error {
 			return nil
 		},
 	})
-
-	return nil
 }
