@@ -26,6 +26,14 @@ func NewConfirmationHelper(c *HelperCommon) *ConfirmationHelper {
 
 func (self *ConfirmationHelper) wrappedConfirmationFunction(cancel goContext.CancelFunc, function func() error) func() error {
 	return func() error {
+		if self.c.GocuiGui().IsPasting {
+			// The user is pasting multi-line text into a prompt; we don't want to handle the
+			// line feeds as "confirm" keybindings. Simply ignoring them is the best we can do; this
+			// will cause the entire pasted text to appear as a single line in the prompt. Hopefully
+			// the user knows that ctrl-u allows them to delete it again...
+			return nil
+		}
+
 		cancel()
 
 		self.c.Context().Pop()
