@@ -132,24 +132,24 @@ func (self *WorktreeHelper) NewWorktreeCheckout(base string, canCheckoutBase boo
 					},
 				})
 
-				return nil
-			} else {
-				// prompt for the new branch name where a blank means we just check out the branch
-				self.c.Prompt(types.PromptOpts{
-					Title: self.c.Tr.NewBranchName,
-					HandleConfirm: func(branchName string) error {
-						if branchName == "" {
-							return errors.New(self.c.Tr.BranchNameCannotBeBlank)
-						}
-
-						opts.Branch = branchName
-
-						return f()
-					},
-				})
-
 				return nil
 			}
+
+			// prompt for the new branch name where a blank means we just check out the branch
+			self.c.Prompt(types.PromptOpts{
+				Title: self.c.Tr.NewBranchName,
+				HandleConfirm: func(branchName string) error {
+					if branchName == "" {
+						return errors.New(self.c.Tr.BranchNameCannotBeBlank)
+					}
+
+					opts.Branch = branchName
+
+					return f()
+				},
+			})
+
+			return nil
 		},
 	})
 
@@ -189,7 +189,8 @@ func (self *WorktreeHelper) Remove(worktree *models.Worktree, force bool) error
 				self.c.LogAction(self.c.Tr.RemoveWorktree)
 				if err := self.c.Git().Worktree.Delete(worktree.Path, force); err != nil {
 					errMessage := err.Error()
-					if !strings.Contains(errMessage, "--force") {
+					if !strings.Contains(errMessage, "--force") &&
+						!strings.Contains(errMessage, "fatal: working trees containing submodules cannot be moved or removed") {
 						return err
 					}
 
@@ -198,7 +199,8 @@ func (self *WorktreeHelper) Remove(worktree *models.Worktree, force bool) error
 					}
 					return err
 				}
-				return self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC, Scope: []types.RefreshableView{types.WORKTREES, types.BRANCHES, types.FILES}})
+				self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC, Scope: []types.RefreshableView{types.WORKTREES, types.BRANCHES, types.FILES}})
+				return nil
 			})
 		},
 	})
@@ -214,7 +216,8 @@ func (self *WorktreeHelper) Detach(worktree *models.Worktree) error {
 		if err != nil {
 			return err
 		}
-		return self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC, Scope: []types.RefreshableView{types.WORKTREES, types.BRANCHES, types.FILES}})
+		self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC, Scope: []types.RefreshableView{types.WORKTREES, types.BRANCHES, types.FILES}})
+		return nil
 	})
 }
 
