@@ -25,6 +25,7 @@ type Views struct {
 
 	Options           *gocui.View
 	Confirmation      *gocui.View
+	Prompt            *gocui.View
 	Menu              *gocui.View
 	CommitMessage     *gocui.View
 	CommitDescription *gocui.View
@@ -34,6 +35,8 @@ type Views struct {
 	AppStatus         *gocui.View
 	Search            *gocui.View
 	SearchPrefix      *gocui.View
+	StatusSpacer1     *gocui.View
+	StatusSpacer2     *gocui.View
 	Limit             *gocui.View
 	Suggestions       *gocui.View
 	Tooltip           *gocui.View
