@@ -4,6 +4,7 @@ import (
 	"time"
 
 	"github.com/jesseduffield/gocui"
+	"github.com/jesseduffield/lazygit/pkg/gui/context"
 	"github.com/jesseduffield/lazygit/pkg/gui/types"
 	"github.com/jesseduffield/lazygit/pkg/tasks"
 	"github.com/jesseduffield/lazygit/pkg/utils"
@@ -136,5 +137,31 @@ func (gui *Gui) postRefreshUpdate(c types.Context) {
 
 	if gui.currentViewName() == c.GetViewName() {
 		c.HandleFocus(types.OnFocusOpts{})
+	} else {
+		// The FocusLine call is included in the HandleFocus method which we
+		// call for focused views above; but we need to call it here for
+		// non-focused views to ensure that an inactive selection is painted
+		// correctly, and that integration tests see the up to date selection
+		// state.
+		c.FocusLine()
+
+		currentCtx := gui.State.ContextMgr.Current()
+		if currentCtx.GetKey() == context.NORMAL_MAIN_CONTEXT_KEY || currentCtx.GetKey() == context.NORMAL_SECONDARY_CONTEXT_KEY {
+			// Searching can't cope well with the view being updated while it is being searched.
+			// We might be able to fix the problems with this, but it doesn't seem easy, so for now
+			// just don't rerender the view while searching, on the assumption that users will probably
+			// either search or change their data, but not both at the same time.
+			if !currentCtx.GetView().IsSearching() {
+				sidePanelContext := gui.State.ContextMgr.NextInStack(currentCtx)
+				if sidePanelContext != nil && sidePanelContext.GetKey() == c.GetKey() {
+					sidePanelContext.HandleRenderToMain()
+				}
+			}
+		} else if c.GetKey() == gui.State.ContextMgr.CurrentStatic().GetKey() {
+			// If our view is not the current one, but it is the current static context, then this
+			// can only mean that a popup is showing. In that case we want to refresh the main view
+			// behind the popup.
+			c.HandleRenderToMain()
+		}
 	}
 }
