@@ -23,8 +23,9 @@ var StashAndKeepIndex = NewIntegrationTest(NewIntegrationTestArgs{
 
 		t.Views().Files().
 			Lines(
-				Contains("file-staged"),
-				Contains("file-unstaged"),
+				Equals("▼ /"),
+				Equals("  M  file-staged"),
+				Equals("   M file-unstaged"),
 			).
 			Press(keys.Files.ViewStashOptions)
 
@@ -39,7 +40,7 @@ var StashAndKeepIndex = NewIntegrationTest(NewIntegrationTestArgs{
 
 		t.Views().Files().
 			Lines(
-				Contains("file-staged"),
+				Equals("M  file-staged"),
 			)
 
 		t.Views().Stash().
@@ -49,8 +50,9 @@ var StashAndKeepIndex = NewIntegrationTest(NewIntegrationTestArgs{
 		t.Views().CommitFiles().
 			IsFocused().
 			Lines(
-				Contains("file-staged"),
-				Contains("file-unstaged"),
+				Equals("▼ /"),
+				Equals("  M file-staged"),
+				Equals("  M file-unstaged"),
 			)
 	},
 })
